Learn R Programming

MSTest (version 0.1.9)

simuVARX: Simulate VARX process

Description

This function simulates a vector autoregressive process with exogenous regressors.

Usage

simuVARX(mdl_h0, burnin = 100)

Value

List with simulated vector autoregressive series and its DGP parameters.

Arguments

mdl_h0

List containing the following DGP parameters

  • n: Length of series.

  • mu: A (q x 1) vector of means.

  • sigma: A (q x q) covariance matrix.

  • phi: A (q x (q x p)) matrix of autoregressive coefficients.

  • p: Number of autoregressive lags.

  • q: Number of series.

  • eps: An optional (T+burnin x q) matrix with standard normal errors to be used. Errors will be generated if not provided.

  • Z: A (T x qz) matrix with exogenous regressors (Optional) and where qz is the number of exogenous variables.

  • betaZ: A (qz x q) matrix true coefficients on exogenous regressors (Optional) and where qz is the number of exogenous variables.

burnin

Number of simulated observations to remove from beginning. Default is 100.

Examples

Run this code
set.seed(1234)
# Define DGP of VAR process
mdl_3var2 <- list(n     = 1000, 
                  p     = 2,
                  q     = 3,
                  mu    = c(5, -2, 1),
                  sigma = rbind(c(5.0, 1.5, 2.5),
                                c(1.5, 1.0, 1.5),
                                c(2.5, 1.5, 4.2)),
                  phi   = rbind(c(0.70, 0.30, 0.35,  -0.50, -0.20,   0.25),
                                c(0.20, 0.40, 0.35,  -0.30,  0.30,   0.25),
                                c(0.20, 0.30, 0.50,  -0.30, -0.20,  -0.40)))

# Simulate process using simuVAR() function
y3var2_simu <- simuVAR(mdl_3var2)

plot(y3var2_simu)

Run the code above in your browser using DataLab