This function computes the Maximum Monte Carlo P-value. When pre-drawn innovations are provided, the same fixed draws are used for every theta evaluation (Dufour 2006, Proposition 4.2).
MMCLRpval_fun(
theta_h0,
mdl_h0,
k1,
LRT_0,
N,
burnin,
workers,
lambda,
stationary_constraint,
thtol,
Z,
exog,
mdl_h0_control,
mdl_h1_control,
predrawn_eps = NULL,
predrawn_state_rand = NULL
)MMC p-value
vector of parameter values under the null being considered.
List with restricted model properties.
integer determining the number of regimes under the alternative.
double specifying the fixed observed likelihood ratio test statistic.
integer specifying the number of replications.
integer specifying the number of observations to drop from beginning of simulation.
Integer determining the number of workers to use for parallel computing.
Double determining penalty on nonlinear constraint.
Boolean determining if only stationary solutions are considered (if TRUE) or not (if FALSE).
double determining the convergence criterion used during estimation.
List with controls/options used to estimate restricted model.
List with controls/options used to estimate unrestricted model.
Optional list of pre-drawn standard normal matrices (fixed across theta evaluations).
Optional matrix of pre-drawn U[0,1] for state transitions.